@@ -8,6 +8,7 @@ from pydoc import locate
 from typing import List, Tuple, Any, Type, get_type_hints, Generic, TypeVar, Dict, Iterator
 
 import dacite
+import numpy as np
 from dacite import from_dict
 from dacite.dataclasses import get_fields
 from silberstral import gather_types, is_type_var_instantiated, reveal_type_var
@@ -105,9 +106,9 @@ class ClassMapping(StringEnum):
 @dataclass
 class Config(ABC):
 
-    @staticmethod
-    def _serialize_enums(items: List[Tuple[str, Any]]):
+    def _serialize_enums_and_numpy(self, items: List[Tuple[str, Any]]):
         d = dict()
+        config_fields = {f.name: f for f in fields(self)}
         for key, value in items:
             if isinstance(value, Enum):
                 value = value.value  # Use the Enum's value as representation for the value
@@ -119,6 +120,22 @@ class Config(ABC):
                     k.value if isinstance(k, Enum) else k:
                         v.value if isinstance(v, Enum) else v
                     for k, v in value.items()}
+            # TODO: due to dacite we can only unpack numpy items at the outer level.
+            #   dacite does iterate through nested configs of course, but here it does not give us access to the fields
+            #   of the nested config...
+            elif key in config_fields \
+                    and (config_fields[key].type == float and (
+                    isinstance(value, np.float32) or isinstance(value, np.float64))
+                         or (config_fields[key].type == int and (
+                            isinstance(value, np.int32) or isinstance(value, np.int64)))
+                         or (config_fields[key].type == bool and isinstance(value, np.bool_))):
+                # If a single valued numpy object was passed, but a built-in Python type was expected, we need to
+                # extract the value from the numpy container. This is for the convenience of the user
+                # Currently implemented casts:
+                #  - np.float32/64 -> float
+                #  - np.int32/64 -> int
+                #  - np.bool_ -> bool
+                value = value.item()
 
             d[key] = value
         return d
@@ -134,7 +151,7 @@ class Config(ABC):
         -------
             a Python dictionary representing this dataclass
         """
-        return asdict(self, dict_factory=Config._serialize_enums)
+        return asdict(self, dict_factory=self._serialize_enums_and_numpy)
 
     def __post_init__(self):
         """
@@ -213,8 +230,11 @@ class Config(ABC):
         field_types = get_type_hints(cls).values()
         # Find all mentioned types in the dataclass definition (even those mentioned as generics)
         for field_type in gather_types(field_types):
-            if inspect.isclass(field_type) and issubclass(field_type, Enum):
-                casts.append(field_type)
+            if inspect.isclass(field_type):
+                # Automatically cast to enums and custom types that were listed in config fields
+                if issubclass(field_type, Enum):  # or not inspect.isbuiltin(field_type):
+                    casts.append(field_type)
+        casts.append(tuple)  # Tuples are stored as [] lists in JSON. Cast them back to tuple here
 
         return casts
 
@@ -281,6 +301,8 @@ class Config(ABC):
                 instantiate_adc_with_sub_class(abstract_dataclass_values, data_sub_class_type)
             for abstract_dataclass, data_sub_class_type
             in zip(abstract_dataclasses, data_sub_class_types)}
+        # Numpy arrays are serialized as lists. Cast them back to np array here
+        type_hooks[np.ndarray] = lambda array_values: np.asarray(array_values)
 
         # Register type hooks to replace every single AbstractDataClass with the respective subclass hinted by the
         # 'type' attribute
