@@ -1,6 +1,6 @@
 from .analysis import Analysis
 from .artifact import ArtifactManager
-from .buffered import BaseDataManager, BufferedDataLoader
+from .buffered import BufferedDataLoader
 from .data import BaseDataManager, BaseSampleDataManager, BaseSliceDataManager, RandomAccessSampleDataManager, \
     RandomAccessSliceDataManager
 from .model import ModelManager
